package zero1hd.polyjet.ui.builders;

import java.io.IOException;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.Preferences;
import com.badlogic.gdx.files.FileHandle;
import com.badlogic.gdx.graphics.Pixmap;
import com.badlogic.gdx.graphics.Texture;
import com.badlogic.gdx.scenes.scene2d.ui.Button;
import com.badlogic.gdx.scenes.scene2d.ui.Image;
import com.badlogic.gdx.scenes.scene2d.ui.Skin;
import com.mpatric.mp3agic.ID3v2;
import com.mpatric.mp3agic.InvalidDataException;
import com.mpatric.mp3agic.Mp3File;
import com.mpatric.mp3agic.UnsupportedTagException;

import zero1hd.wavedecoder.WavInfo;

public class MusicSelectable extends Button {
	Image imageIcon;
	FileHandle musicFile;
	boolean invalidMusic;
	long durationInSeconds;
	String songName;
	
	WavInfo wavinfo;
	private byte[] albumWorkBytes;
	
	public MusicSelectable(FileHandle musicFile, Preferences musicData, Skin skin) {
		super(skin, "info-button");
		
		this.musicFile = musicFile;
		
		if (musicFile.extension().toLowerCase().equals("mp3")) {
			try {
				Mp3File mp3File = new Mp3File(musicFile.file());
				durationInSeconds = mp3File.getLengthInSeconds();
				
				if (mp3File.hasId3v2Tag()) {
					ID3v2 id3v2tag = mp3File.getId3v2Tag();
					albumWorkBytes = id3v2tag.getAlbumImage();
					
					songName = id3v2tag.getTitle();
				}
			} catch (UnsupportedTagException | InvalidDataException | IOException e) {
				Gdx.app.debug("Music Selector", "Error while reading tag for " + musicFile.name());
			}
			
		} else {
			wavinfo = new WavInfo(musicFile.file());
			durationInSeconds = wavinfo.getDurationInSeconds();
		}
		if (durationInSeconds > 60 * 5) {
			invalidMusic = true;
		}
		if (songName == null || songName.isEmpty()) {
			songName = musicFile.name();
		}
	}
	
	public void renderAlbumCover() {
		if (albumWorkBytes != null) {
			Pixmap albumArt = new Pixmap(albumWorkBytes, 0, albumWorkBytes.length);
			Texture albumArtTexture = new Texture(albumArt);
			imageIcon = new Image(albumArtTexture);
			float scale = 0.25f*getHeight()/imageIcon.getHeight();
			imageIcon.setScale(scale);
			
			add(imageIcon);
			albumArtTexture.dispose();
		} else {
			//TODO load default album cover texture
		}
	}
	
}
